@@ -12,9 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Ryan Lortie <desrt@desrt.ca>
  */
@@ -240,8 +238,12 @@ app_path_for_id (const gchar *app_id)
 
   path = g_strconcat ("/", app_id, NULL);
   for (i = 0; path[i]; i++)
-    if (path[i] == '.')
-      path[i] = '/';
+    {
+      if (path[i] == '.')
+        path[i] = '/';
+      if (path[i] == '-')
+        path[i] = '_';
+    }
 
   return path;
 }
@@ -295,7 +297,7 @@ app_get_platform_data (void)
 
   g_variant_builder_init (&builder, G_VARIANT_TYPE_VARDICT);
 
-  if ((startup_id = g_getenv ("DESKTOP_STARTUP_iD")))
+  if ((startup_id = g_getenv ("DESKTOP_STARTUP_ID")))
     g_variant_builder_add (&builder, "{sv}", "desktop-startup-id", g_variant_new_string (startup_id));
 
   return g_variant_builder_end (&builder);
