@@ -357,8 +357,8 @@ static void
 settings_backend_keys_changed (GObject             *target,
                                GSettingsBackend    *backend,
                                const gchar         *path,
-                               const gchar * const *items,
-                               gpointer             origin_tag)
+                               gpointer             origin_tag,
+                               const gchar * const *items)
 {
   GSettings *settings = G_SETTINGS (target);
   gboolean ignore_this;
@@ -988,14 +988,14 @@ g_settings_new_with_backend_and_path (const gchar      *schema_id,
  * backend, and a #GMainContext to which signals are dispatched.
  *
  * This constructor therefore gives you full control over constructing
- * #GSettings instances.  The first 4 parameters are given directly as
+ * #GSettings instances.  The first 3 parameters are given directly as
  * @schema, @backend and @path, and the main context is taken from the
  * thread-default (as per g_settings_new()).
  *
  * If @backend is %NULL then the default backend is used.
  *
  * If @path is %NULL then the path from the schema is used.  It is an
- * error f @path is %NULL and the schema has no path of its own or if
+ * error if @path is %NULL and the schema has no path of its own or if
  * @path is non-%NULL and not equal to the path that the schema does
  * have.
  *
