@@ -1428,7 +1428,7 @@
  * sign, mantissa and exponent of IEEE floats and doubles. These unions are
  * defined as appropriate for a given platform. IEEE floats and doubles are
  * supported (used for storage) by at least Intel, PPC and Sparc. See
- * <ulink url="http://en.wikipedia.org/wiki/IEEE_float">IEEE 754-2008</ulink>
+ * [IEEE 754-2008](http://en.wikipedia.org/wiki/IEEE_float)
  * for more information about IEEE number formats.
  */
 
@@ -1526,14 +1526,14 @@
  * G_OS_WIN32:
  *
  * This macro is defined only on Windows. So you can bracket
- * Windows-specific code in "&num;ifdef G_OS_WIN32".
+ * Windows-specific code in "\#ifdef G_OS_WIN32".
  */
 
 /**
  * G_OS_UNIX:
  *
  * This macro is defined only on UNIX. So you can bracket
- * UNIX-specific code in "&num;ifdef G_OS_UNIX".
+ * UNIX-specific code in "\#ifdef G_OS_UNIX".
  */
 
 /**
@@ -1702,7 +1702,7 @@
  * arrays or arrays on the stack.
  */
  
-/ * Miscellaneous Macros {{{1 */
+/* Miscellaneous Macros {{{1 */
 
 /**
  * SECTION:macros_misc
@@ -1859,7 +1859,7 @@
  *
  * Expands to __extension__ when gcc is used as the compiler. This simply
  * tells gcc not to warn about the following non-standard code when compiling
- * with the <option>-pedantic</option> option.
+ * with the `-pedantic` option.
  */
 
 /**
@@ -1950,7 +1950,7 @@
  *
  * Expands to the GNU C deprecated attribute if the compiler is gcc.
  * It can be used to mark typedefs, variables and functions as deprecated.
- * When called with the <option>-Wdeprecated-declarations</option> option,
+ * When called with the `-Wdeprecated-declarations` option,
  * gcc will generate warnings when deprecated interfaces are used.
  *
  * Place the attribute after the declaration, just before the semicolon.
@@ -1990,8 +1990,8 @@
  * regression tests for deprecated functions.
  *
  * Use %G_GNUC_END_IGNORE_DEPRECATIONS to begin warning again. (If you
- * are not compiling with <literal>-Wdeprecated-declarations</literal>
- * then neither macro has any effect.)
+ * are not compiling with `-Wdeprecated-declarations` then neither macro
+ * has any effect.)
  *
  * This macro can be used either inside or outside of a function body,
  * but must appear on a line by itself.
@@ -2199,7 +2199,7 @@
  * Expands to the GNU C no_instrument_function function attribute if the
  * compiler is gcc. Functions with this attribute will not be instrumented
  * for profiling, when the compiler is called with the
- * <option>-finstrument-functions</option> option.
+ * `-finstrument-functions` option.
  *
  * Place the attribute after the declaration, just before the semicolon.
  *
@@ -2294,6 +2294,12 @@
  * Since: 2.4
  */
 
+/**
+ * G_HAVE_GNUC_VISIBILITY:
+ *
+ * Defined to 1 if gcc-style visibility handling is supported.
+ */
+
 /* Windows Compatibility Functions {{{1 */
 
 /**
@@ -2319,8 +2325,8 @@
  * @static: empty or "static"
  * @dll_name: the name of the (pointer to the) char array where
  *     the DLL name will be stored. If this is used, you must also
- *     include <filename>windows.h</filename>. If you need a more
- *     complex DLL entry point function, you cannot use this
+ *     include `windows.h`. If you need a more complex DLL entry
+ *     point function, you cannot use this
  *
  * On Windows, this macro defines a DllMain() function that stores
  * the actual DLL name that the code being compiled will be included in.
