@@ -944,6 +944,8 @@ g_date_time_new (GTimeZone *tz,
   GDateTime *datetime;
   gint64 full_time;
 
+  g_return_val_if_fail (tz != NULL, NULL);
+
   if (year < 1 || year > 9999 ||
       month < 1 || month > 12 ||
       day < 1 || day > 31 ||
@@ -1654,7 +1656,7 @@ g_date_time_get_day_of_month (GDateTime *datetime)
  * calendar year (so that these days have the same week-numbering year
  * as the Thursday occurring early in the next year).
  *
- * For Friday, Saturaday and Sunday occurring near the start of the year,
+ * For Friday, Saturday and Sunday occurring near the start of the year,
  * this may mean that the week-numbering year is one less than the
  * calendar year (so that these days have the same week-numbering year
  * as the Thursday occurring late in the previous year).
